IndexReader

Struct IndexReader 

pub struct IndexReader {
    pub seq_base: u64,
    /* private fields */
}
Reads index entries from a .idx sidecar file.

Fields

seq_base: u64

Implementations

Source

impl IndexReader

pub fn open(path: &Path) -> Result<Option<Self>>

Open an existing index file. Returns Ok(None) if the file is too small, has wrong magic, or wrong version.

pub fn line_count(&self) -> usize

Number of lines indexed in this file.

pub fn read_record(&mut self, line: usize) -> Result<IndexRecord>

Read a single record by 0-based line number.

pub fn read_range( &mut self, start: usize, count: usize, ) -> Result<Vec<IndexRecord>>

Read records [start..start+count), clamped to available lines.

pub fn line_count_from_metadata(path: &Path) -> Result<usize>

Compute line count from file metadata without reading content.