bind_proxy_port

Function bind_proxy_port 

pub fn bind_proxy_port(
    explicit: Option<u16>,
) -> Result<(TcpListener, u16), ProxyError>
Bind an available port for the proxy listener, returning the bound listener. Eliminates TOCTOU by keeping the listener alive between finding and using the port.