pub struct OutputBuffer { /* private fields */ }Expand description
Single ring buffer storing all output with source tags. Stdout/stderr views are filtered from the same data — no duplication.
Implementations
Sourceimpl OutputBuffer
impl OutputBuffer
pub fn new(max_lines: usize) -> Self
pub fn push(&mut self, source: LineSource, line: String)
pub fn is_empty(&self) -> bool
Sourcepub fn stdout_count(&self) -> usize
pub fn stdout_count(&self) -> usize
O(1) count of stdout lines.
Sourcepub fn stderr_count(&self) -> usize
pub fn stderr_count(&self) -> usize
O(1) count of stderr lines.
pub fn stdout_lines(&self) -> impl Iterator<Item = &str>
pub fn stderr_lines(&self) -> impl Iterator<Item = &str>
pub fn all_lines(&self) -> impl Iterator<Item = (LineSource, &str)>